aboutsummaryrefslogtreecommitdiffstats
path: root/src/vnet/policer/xlate.h
diff options
context:
space:
mode:
authorBrian Russell <brian@graphiant.com>2021-02-09 10:16:58 +0000
committerNeale Ranns <neale@graphiant.com>2021-02-12 14:55:58 +0000
commitc5299ff30a6186f580509eda2c4db3decfffe967 (patch)
tree019738ecade99e21539171dab723b4cba0bc7d72 /src/vnet/policer/xlate.h
parentcf0102b3ba69cb6bad6b1bae159e51976e2331f8 (diff)
policer: remove SSE2 prefix
The policer code uses a naming convention of prefixing a lot of its definitions with "SSE2" when in fact there is nothing SSE2 specific about them. This is confusing so remove the prefix. Unfortunately it has to stay in the API definitions for backward compatibility. Type: improvement Signed-off-by: Brian Russell <brian@graphiant.com> Change-Id: I59a7df9fd5ded2575f2e587b2768a025a213b07c
Diffstat (limited to 'src/vnet/policer/xlate.h')
-rw-r--r--src/vnet/policer/xlate.h90
1 files changed, 43 insertions, 47 deletions
diff --git a/src/vnet/policer/xlate.h b/src/vnet/policer/xlate.h
index 535006569f5..101c07074f2 100644
--- a/src/vnet/policer/xlate.h
+++ b/src/vnet/policer/xlate.h
@@ -24,18 +24,18 @@
#include <vnet/policer/police.h>
/*
- * edt: * enum sse2_qos_policer_type_en
+ * edt: * enum qos_policer_type_en
* Defines type of policer to be allocated
*/
-typedef enum sse2_qos_policer_type_en_
+typedef enum qos_policer_type_en_
{
- SSE2_QOS_POLICER_TYPE_1R2C = 0,
- SSE2_QOS_POLICER_TYPE_1R3C_RFC_2697 = 1,
- SSE2_QOS_POLICER_TYPE_2R3C_RFC_2698 = 2,
- SSE2_QOS_POLICER_TYPE_2R3C_RFC_4115 = 3,
- SSE2_QOS_POLICER_TYPE_2R3C_RFC_MEF5CF1 = 4,
- SSE2_QOS_POLICER_TYPE_MAX
-} sse2_qos_policer_type_en;
+ QOS_POLICER_TYPE_1R2C = 0,
+ QOS_POLICER_TYPE_1R3C_RFC_2697 = 1,
+ QOS_POLICER_TYPE_2R3C_RFC_2698 = 2,
+ QOS_POLICER_TYPE_2R3C_RFC_4115 = 3,
+ QOS_POLICER_TYPE_2R3C_RFC_MEF5CF1 = 4,
+ QOS_POLICER_TYPE_MAX
+} qos_policer_type_en;
/*
* edt: * enum
@@ -43,11 +43,11 @@ typedef enum sse2_qos_policer_type_en_
*/
typedef enum
{
- SSE2_QOS_ROUND_TO_CLOSEST = 0,
- SSE2_QOS_ROUND_TO_UP,
- SSE2_QOS_ROUND_TO_DOWN,
- SSE2_QOS_ROUND_INVALID
-} sse2_qos_round_type_en;
+ QOS_ROUND_TO_CLOSEST = 0,
+ QOS_ROUND_TO_UP,
+ QOS_ROUND_TO_DOWN,
+ QOS_ROUND_INVALID
+} qos_round_type_en;
/*
* edt: * enum
@@ -56,15 +56,15 @@ typedef enum
*
* Default of zero is kbps, which is inline with how it is programmed
* in actual hardware. However, the warning is that this is reverse logic
- * of units_in_bits field in sse2_static_policer_parameters_st, which is
+ * of units_in_bits field in static_policer_parameters_st, which is
* inline with sse_punt_drop.h.
*/
typedef enum
{
- SSE2_QOS_RATE_KBPS = 0,
- SSE2_QOS_RATE_PPS,
- SSE2_QOS_RATE_INVALID
-} sse2_qos_rate_type_en;
+ QOS_RATE_KBPS = 0,
+ QOS_RATE_PPS,
+ QOS_RATE_INVALID
+} qos_rate_type_en;
/*
* edt: * enum
@@ -72,28 +72,28 @@ typedef enum
*/
typedef enum
{
- SSE2_QOS_ACTION_DROP = 0,
- SSE2_QOS_ACTION_TRANSMIT,
- SSE2_QOS_ACTION_MARK_AND_TRANSMIT
-} sse2_qos_action_type_en;
+ QOS_ACTION_DROP = 0,
+ QOS_ACTION_TRANSMIT,
+ QOS_ACTION_MARK_AND_TRANSMIT
+} qos_action_type_en;
/*
- * edt * struct sse2_qos_pol_action_params_st
+ * edt * struct qos_pol_action_params_st
* This structure is used to hold user configured police action parameters.
*
* element: action_type
- * Action type (see sse2_qos_action_type_en).
+ * Action type (see qos_action_type_en).
* element: dscp
* DSCP value to set when action is SSE2_QOS_ACTION_MARK_AND_TRANSMIT.
*/
-typedef struct sse2_qos_pol_action_params_st_
+typedef struct qos_pol_action_params_st_
{
u8 action_type;
ip_dscp_t dscp;
-} sse2_qos_pol_action_params_st;
+} qos_pol_action_params_st;
/*
- * edt: * struct sse2_qos_pol_cfg_params_st
+ * edt: * struct qos_pol_cfg_params_st
*
* Description:
* This structure is used to hold user configured policing parameters.
@@ -118,12 +118,12 @@ typedef struct sse2_qos_pol_action_params_st_
* Indicates the union if in kbps/bytes or pps/ms.
* element: rfc
* Policer algorithm - 1R2C, 1R3C (2697), 2R3C (2698) or 2R3C (4115). See
- * sse_qos_policer_type_en
+ * qos_policer_type_en
* element: rnd_type
* Rounding type (see sse_qos_round_type_en). Needed when policer values
* need to be rounded. Caller can decide on type of rounding used
*/
-typedef struct sse2_qos_pol_cfg_params_st_
+typedef struct qos_pol_cfg_params_st_
{
union
{
@@ -142,20 +142,19 @@ typedef struct sse2_qos_pol_cfg_params_st_
u64 eb_ms;
} pps;
} rb; /* rate burst config */
- u8 rate_type; /* sse2_qos_rate_type_en */
- u8 rnd_type; /* sse2_qos_round_type_en */
- u8 rfc; /* sse2_qos_policer_type_en */
+ u8 rate_type; /* qos_rate_type_en */
+ u8 rnd_type; /* qos_round_type_en */
+ u8 rfc; /* qos_policer_type_en */
u8 color_aware;
u8 overwrite_bucket; /* for debugging purposes */
u32 current_bucket; /* for debugging purposes */
u32 extended_bucket; /* for debugging purposes */
- sse2_qos_pol_action_params_st conform_action;
- sse2_qos_pol_action_params_st exceed_action;
- sse2_qos_pol_action_params_st violate_action;
-} sse2_qos_pol_cfg_params_st;
+ qos_pol_action_params_st conform_action;
+ qos_pol_action_params_st exceed_action;
+ qos_pol_action_params_st violate_action;
+} qos_pol_cfg_params_st;
-
-typedef struct sse2_qos_pol_hw_params_st_
+typedef struct qos_pol_hw_params_st_
{
u8 rfc;
u8 allow_negative;
@@ -168,13 +167,10 @@ typedef struct sse2_qos_pol_hw_params_st_
u8 extd_bkt_limit_man;
u32 comm_bkt;
u32 extd_bkt;
-} sse2_qos_pol_hw_params_st;
-
-
-int
-sse2_pol_logical_2_physical (sse2_qos_pol_cfg_params_st * cfg,
- policer_read_response_type_st * phys);
+} qos_pol_hw_params_st;
+int pol_logical_2_physical (qos_pol_cfg_params_st *cfg,
+ policer_read_response_type_st *phys);
#endif /* __included_xlate_h__ */
@@ -72,28 +72,28 @@ typedef enum
* element: dscp
- * DSCP value to set when action is SSE2_QOS_ACTION_MARK_AND_TRANSMIT.
+ * DSCP value to set when action is QOS_ACTION_MARK_AND_TRANSMIT.
*/
@@ -118,12 +118,12 @@ typedef struct sse2_qos_pol_action_params_st_
* element: rnd_type
- * Rounding type (see sse_qos_round_type_en). Needed when policer values
+ * Rounding type (see qos_round_type_en). Needed when policer values
* need to be rounded. Caller can decide on type of rounding used
*/